@@ -1,5 +1,5 @@
 """Base class used by radiance schema objects."""
-from pydantic import Field, validator, BaseModel
+from pydantic import Field, validator
 import re
 from .._base import NoExtraBaseModel
 
