@@ -6,20 +6,23 @@ from .modifier import _REFERENCE_UNION_MODIFIERS
 from .modifierset import ModifierSet, ModifierSetAbridged
 from .._base import NoExtraBaseModel
 
+from honeybee_schema.radiance.state import RadianceShadeStateAbridged, \
+    RadianceSubFaceStateAbridged
+
 
 class _PropertiesBaseAbridged(NoExtraBaseModel):
     """Base class of Abridged Radiance Properties."""
 
     modifier: str = Field(
         default=None,
-        description='A string for a Honeybee Radiance Modifier.'
+        description='A string for a Honeybee Radiance Modifier (default: None).'
         )
 
     modifier_blk: str = Field(
         default=None,
         description='A string for a Honeybee Radiance Modifier to be used '
                     'in direct solar simulations and in isolation studies (assessing'
-                    'the contribution of individual objects).'
+                    'the contribution of individual objects) (default: None).'
         )
 
 
@@ -29,6 +32,19 @@ class ApertureRadiancePropertiesAbridged(_PropertiesBaseAbridged):
     type: constr(regex='^ApertureRadiancePropertiesAbridged$') = \
         'ApertureRadiancePropertiesAbridged'
 
+    dynamic_group_identifier: str = Field(
+        default=None,
+        description="An optional string to note the dynamic group ' \
+            'to which the Aperture is a part of. Apertures sharing the same ' \
+            'dynamic_group_identifier will have their states change in unison. ' \
+            'If None, the Aperture is assumed to be static. (default: None)."
+    )
+
+    states: List[RadianceSubFaceStateAbridged] = Field(
+        default=None,
+        description="An optional list of abridged states (default: None)."
+    )
+
 
 class DoorRadiancePropertiesAbridged(_PropertiesBaseAbridged):
     """Radiance Properties for Honeybee Door Abridged."""
@@ -36,6 +52,19 @@ class DoorRadiancePropertiesAbridged(_PropertiesBaseAbridged):
     type: constr(regex='^DoorRadiancePropertiesAbridged$') = \
         'DoorRadiancePropertiesAbridged'
 
+    dynamic_group_identifier: str = Field(
+        default=None,
+        description="An optional string to note the dynamic group ' \
+            'to which the Door is a part of. Doors sharing the same ' \
+            'dynamic_group_identifier will have their states change in unison. ' \
+            'If None, the Door is assumed to be static. (default: None)."
+    )
+
+    states: List[RadianceSubFaceStateAbridged] = Field(
+        default=None,
+        description="An optional list of abridged states (default: None)."
+    )
+
 
 class FaceRadiancePropertiesAbridged(_PropertiesBaseAbridged):
     """Radiance Properties for Honeybee Face Abridged."""
@@ -50,6 +79,19 @@ class ShadeRadiancePropertiesAbridged(_PropertiesBaseAbridged):
     type: constr(regex='^ShadeRadiancePropertiesAbridged$') = \
         'ShadeRadiancePropertiesAbridged'
 
+    dynamic_group_identifier: str = Field(
+        default=None,
+        description="An optional string to note the dynamic group ' \
+            'to which the Shade is a part of. Shades sharing the same ' \
+            'dynamic_group_identifier will have their states change in unison. ' \
+            'If None, the Shade is assumed to be static. (default: None)."
+    )
+
+    states: List[RadianceShadeStateAbridged] = Field(
+        default=None,
+        description="An optional list of abridged states (default: None)."
+    )
+
 
 class RoomRadiancePropertiesAbridged(NoExtraBaseModel):
     """Abridged Radiance Properties for Honeybee Room."""
@@ -70,22 +112,22 @@ class ModelRadianceProperties(NoExtraBaseModel):
     type: constr(regex='^ModelRadianceProperties$') = 'ModelRadianceProperties'
 
     modifiers: List[_REFERENCE_UNION_MODIFIERS] = Field(
-        default=[],
+        default=None,
         description='A list of all unique modifiers in the model. '
-                    'This includes modifiers across all Faces, Apertures, Doors, Shades, '
-                    'Room ModifierSets, and the global_modifier_set. (default: []).'
+                    'This includes modifiers across all Faces, Apertures, Doors, '
+                    'Shades, Room ModifierSets, and the global_modifier_set '
+                    '(default: None).'
         )
 
     modifier_sets: List[Union[ModifierSet, ModifierSetAbridged]] = Field(
-        default=[],
+        default=None,
         description='A list of all unique Room-Assigned ModifierSets in the Model '
-                    '(default: []).'
+                    '(default: None).'
         )
 
     global_modifier_set: str = Field(
         default=None,
-        description='Identifier of a ModifierSet or ModifierSetAbridged object to be used as '
-                    'as a default object for all unassigned objects in the Model '
-                    '(default: None).'
-    )
-
+        description='Identifier of a ModifierSet or ModifierSetAbridged object to be '
+                    'used as as a default object for all unassigned objects in the '
+                    'Model (default: None).'
+        )
