@@ -26,7 +26,8 @@ from honeybee_energy.lib.constructions import generic_exterior_wall, \
 
 from honeybee_radiance.modifierset import ModifierSet
 from honeybee_radiance.modifier.material import Glass, Plastic, Trans
-from honeybee_radiance.state import RadianceShadeState, RadianceSubFaceState
+from honeybee_radiance.dynamic import RadianceShadeState, RadianceSubFaceState, \
+    StateGeometry
 
 from ladybug_geometry.geometry3d.pointvector import Point3D, Vector3D
 from ladybug_geometry.geometry3d.plane import Plane
@@ -82,7 +83,6 @@ def model_complete_single_zone_office(directory):
     room.add_indoor_shade(table)
 
     model = Model('Tiny_House', [room], orphaned_shades=[tree_canopy])
-    model.north_angle = 15
 
     model_dict = model.to_dict()
 
@@ -345,7 +345,6 @@ def model_energy_fixed_interval(directory):
     tree_canopy.properties.energy.transmittance_schedule = trans_sched
 
     model = Model('Tiny_House', [room], orphaned_shades=[tree_canopy])
-    model.north_angle = 15
 
     dest_file = os.path.join(
         directory, 'model_energy_fixed_interval.json')
@@ -395,7 +394,6 @@ def model_energy_no_program(directory):
     room.add_indoor_shade(table)
 
     model = Model('Tiny_House', [room], orphaned_shades=[tree_canopy])
-    model.north_angle = 15
 
     dest_file = os.path.join(directory, 'model_energy_no_program.json')
     with open(dest_file, 'w') as fp:
@@ -457,7 +455,7 @@ def model_radiance_dynamic_states(directory):
 
     south_face = room[3]
     south_face.apertures_by_ratio(0.5, 0.01)
-    shd1 = Shade.from_vertices(
+    shd1 = StateGeometry.from_vertices(
         'outdoor_awning', [[0, 0, 2], [5, 0, 2], [5, 2, 2], [0, 2, 2]])
 
     ecglass1 = Glass.from_single_transmittance('ElectrochromicState1', 0.4)
